Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(14)

Unified Diff: trychange.py

Issue 275383003: Renamed Tryjob label to Tryjob-Request (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/tools/depot_tools
Patch Set: Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: trychange.py
diff --git a/trychange.py b/trychange.py
index fc9c1eb1f2fd27283c2bcd0fa6572ee781281f72..abc89ff70b313365e9b46ab5de5edd98e4dba9eb 100755
--- a/trychange.py
+++ b/trychange.py
@@ -722,7 +722,7 @@ def _SendChangeGerrit(bot_spec, options):
Reads Change-Id from the HEAD commit, resolves the current revision, checks
that local revision matches the uploaded one, posts a try job in form of a
message, sets Tryjob label to 1.
Gerrit message format: starts with !tryjob, optionally followed by a tryjob
definition in JSON format:
@@ -768,7 +768,7 @@ def _SendChangeGerrit(bot_spec, options):
# Post a message and set TryJob=1 label.
try:
gerrit_util.SetReview(gerrit_host, change_id, msg=message,
- labels={'Tryjob': 1})
+ labels={'Tryjob-Request': 1})
except gerrit_util.GerritError, e:
if e.http_status == 400:
raise Error(e.reason)
@@ -722,7 +722,7 @@ def _SendChangeGerrit(bot_spec, options):
Reads Change-Id from the HEAD commit, resolves the current revision, checks
that local revision matches the uploaded one, posts a try job in form of a
- message, sets Tryjob label to 1.
+ message, sets Tryjob-Request label to 1.
Gerrit message format: starts with !tryjob, optionally followed by a tryjob
definition in JSON format:
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698